==> nextcloud-15.0.5p1.tgz: nextcloud/apps/firstrunwizard/l10n/es_CL.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Asistente de Ejecución Inicial",
    "Add your profile information! For example your email is needed to reset your password." : "¡Agregua tu información de perfil! Por ejemplo tu correo electrónico es necesario para restablecer tu contraseña.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "¡Agregua tu información de perfil! Establece una imagen de perfil y nombre completo para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a full name for easier recognition across all features." : "Agregua tu información de perfil! Establece tu nombre completo para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Agrega tu información de perfil! Establece una imagen de perfil para reconocerte más fácilmente entre todas las funcionalidades. ",
    "About" : "Acerca de",
    "Previous" : "Previo",
    "Next" : "Siguiente",
    "Start using Nextcloud" : "Empieza a usar Nextcloud",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "Puedes encontrar más de 100 apliicaciones en la tienda de aplicaciones de Nextcloud y personalizar tu nube:",
    "Groupware apps like Calendar, Contacts, Mail" : "Aplicaciones de Groupware como Calendario, Contactos y Correo",
    "Communication with Nextcloud Talk" : "Comunicacion con Nextcloud Talk",
    "Collaboration apps for document editing" : "Aplicaciones de colaboración para edicion de documentos",
    "Browse the app store" : "Navega la tienda de aplicaciones",
    "Stay in sync" : "Mantener sincronizado",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud te da acceso a tus achivos en donde quiera que estes. ",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "¡Nuestros clientes de fácil uso para escritorio y móviles están disponibles para la mayoría de las plataformas sin costo alguno!",
    "Get the apps to sync your files" : "Obten las aplicaciones para sincronizar tus archivos",
    "Desktop client" : "Cliente de escritorio",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "Connect your desktop apps to %s" : "Conecta tu aplicación de escritorio a %s",
    "Connect your calendar" : "Conecta tu calendario",
    "Connect your contacts" : "Conecta tus contactos",
    "Access files via WebDAV" : "Accede tus archivos vía WebDAV",
    "Get help" : "Obten ayuda",
    "Get more information" : "Obten más información",
    "The Nextcloud documentation for home users:" : "La documentación de Nextcloud para usuarios particulares:",
    "User manual" : "Manual de usuario",
    "Admin manual" : "Manual del administrador",
    "Developer manual" : "Manual del desarrollador",
    "You can also ask for help in our community support channels:" : "También puedes pedir ayuda en nuestros canales de soporte de la comunidad:",
    "the Nextcloud forums" : "en los foros de Nextcloud",
    "the Nextcloud IRC chat channel on freenode.net" : "el canal del chat de IRC para Nextcloud en freenode.net",
    "Start contributing" : "Empeiza a contribuir",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "¿Desas tener alguna mejora específica en Nextcloud? ¿Encontraste aglún problema? ¿Quieres ayudarnos a traducir, promover o documentar Nextcloud?",
    "Enterprise support" : "Soporte empresarial",
    "Get enterprise support" : "Obten soporte empresarial",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud deja tus datos a tu alcance, bajo tu control. Almacena tus documentos, calendario, contactos y fotografías en un servidor de tu compañia, en casa, con uno de nuestros proveedores o en un centro de datos que conozcas. ",
    "Open Standards and Interoperability" : "Estándares Abiertos e Interoperabilidad",
    "100%% Open Source & community-focused" : "100%% Código Abierto & orientado a la comunidad",
    "Learn more about %s" : "Más información de %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s te da acceso a tus archivos donde te encuentres. Nuestros clientes intuitivos para escritorio y móviles estan disponibles para la mayoria de las plataformas sin costo alguno. ",
    "Connect other apps to %s" : "Conectar otras aplicaciones a %s",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Además tu los clientes de sincronización puedes conectar cualquier otro software que soporte los protocolos WebDAV/CalDAV/CardDAV a %s.",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Si deseas soportar el proyecto ¡{contributeopen}únete al desarrollo{linkclose} o {contributeopen}pasa la voz{linkclose}!",
    "Show First Run Wizard again" : "Mostrar el Asistente de Ejecución Inicial de nuevo",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Accede & comparte tus archivos, calendarios, contactos, correo & más desde cualquier dispositivo, en tus propios términos",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Puedes encontrar más información en la <a target=\"_blank\" href=\"%s\">documentación</a> y en nuestro <a target=\"_blank\" href=\"%s\">sitio web</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Si te agrada NextCloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud es un gran software abierto para sincronizar y compartir sus archivos. Puede obtenerlo de forma gratuita desde https://nextcloud.com\"> recomiéndalo a tus amigos</a> y <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribuye</a>!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.3.tgz: nextcloud/apps/firstrunwizard/l10n/es_CL.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Copiar al portapapeles",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "First run wizard" : "Asistente de Ejecución Inicial",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "¡Agregua tu información de perfil! Establece una imagen de perfil y nombre completo para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a full name for easier recognition across all features." : "Agregua tu información de perfil! Establece tu nombre completo para reconocerte más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Agrega tu información de perfil! Establece una imagen de perfil para reconocerte más fácilmente entre todas las funcionalidades. ",
    "About" : "Acerca de",
    "Groupware apps like Calendar, Contacts, Mail" : "Aplicaciones de Groupware como Calendario, Contactos y Correo",
    "Communication with Nextcloud Talk" : "Comunicacion con Nextcloud Talk",
    "Collaboration apps for document editing" : "Aplicaciones de colaboración para edicion de documentos",
    "Stay in sync" : "Mantener sincronizado",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud te da acceso a tus achivos en donde quiera que estes. ",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "¡Nuestros clientes de fácil uso para escritorio y móviles están disponibles para la mayoría de las plataformas sin costo alguno!",
    "Get the apps to sync your files" : "Obten las aplicaciones para sincronizar tus archivos",
    "Desktop client" : "Cliente de escritorio",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "Connect your desktop apps to %s" : "Conecta tu aplicación de escritorio a %s",
    "Connect your calendar" : "Conecta tu calendario",
    "Connect your contacts" : "Conecta tus contactos",
    "Access files via WebDAV" : "Accede tus archivos vía WebDAV",
    "Get help" : "Obten ayuda",
    "Get more information" : "Obten más información",
    "The Nextcloud documentation for home users:" : "La documentación de Nextcloud para usuarios particulares:",
    "User manual" : "Manual de usuario",
    "Admin manual" : "Manual del administrador",
    "Developer manual" : "Manual del desarrollador",
    "You can also ask for help in our community support channels:" : "También puedes pedir ayuda en nuestros canales de soporte de la comunidad:",
    "the Nextcloud forums" : "en los foros de Nextcloud",
    "the Nextcloud IRC chat channel on freenode.net" : "el canal del chat de IRC para Nextcloud en freenode.net",
    "Start contributing" : "Empeiza a contribuir",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "¿Desas tener alguna mejora específica en Nextcloud? ¿Encontraste aglún problema? ¿Quieres ayudarnos a traducir, promover o documentar Nextcloud?",
    "Enterprise support" : "Soporte empresarial",
    "Get enterprise support" : "Obten soporte empresarial",
    "A safe home for all your data" : "Un lugar seguro para todos tus datos",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud deja tus datos a tu alcance, bajo tu control. Almacena tus documentos, calendario, contactos y fotografías en un servidor de tu compañia, en casa, con uno de nuestros proveedores o en un centro de datos que conozcas. ",
    "Open Standards and Interoperability" : "Estándares Abiertos e Interoperabilidad",
    "100%% Open Source & community-focused" : "100%% Código Abierto & orientado a la comunidad",
    "Learn more about %s" : "Más información de %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s te da acceso a tus archivos donde te encuentres. Nuestros clientes intuitivos para escritorio y móviles estan disponibles para la mayoria de las plataformas sin costo alguno. ",
    "Connect other apps to %s" : "Conectar otras aplicaciones a %s",
    "Server address" : "Dirección del servidor",
    "Copy link" : "Copiar liga",
    "Add your profile information! For example your email is needed to reset your password." : "¡Agregua tu información de perfil! Por ejemplo tu correo electrónico es necesario para restablecer tu contraseña.",
    "Start using Nextcloud" : "Empieza a usar Nextcloud",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "Puedes encontrar más de 100 apliicaciones en la tienda de aplicaciones de Nextcloud y personalizar tu nube:",
    "Browse the app store" : "Navega la tienda de aplicaciones",
    "Previous" : "Previo",
    "Next" : "Siguiente"
},
"nplurals=2; plural=(n != 1);");
